;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'skk-kakasi '("skk-kakasi"))
(custom-add-loads 'skk '("skk-auto" "skk-comp" "skk-gadget" "skk-isearch" "skk-kakasi" "skk-kcode" "skk-look" "skk-num" "skk-server" "skk-tut" "skk"))
(custom-add-loads 'skk-server '("skk-server"))
(custom-add-loads 'skk-kcode '("skk-kcode"))
(custom-add-loads 'skk-comp '("skk-comp"))
(custom-add-loads 'skk-gadget '("skk-gadget"))
(custom-add-loads 'input-method '("skk"))
(custom-add-loads 'skk-look '("skk-look"))
(custom-add-loads 'skk-faces '("skk-tut"))
(custom-add-loads 'skk-isearch '("skk-isearch"))
(custom-add-loads 'faces '("skk"))
(custom-add-loads 'skk-auto '("skk-auto"))
(custom-add-loads 'skk-tut '("skk-tut"))
(custom-add-loads 'skk-num '("skk-num"))
(custom-add-loads 'japanese '("skk"))

;;; custom-load.el ends here
